@@ -19,3 +19,11 @@ def git_url_substitutions(fake_process):
     )
 
     fake_process.register(cmd, stdout=stdout)
+
+
+@pytest.fixture(autouse=True)
+def published_projects(monkeypatch):
+    monkeypatch.setenv(
+        'PROJECTS_LIST_URL',
+        'https://www.dropbox.com/s/g16c8w9i7lg9dqn/projects.txt?dl=1',
+    )
